@@ -31,6 +31,23 @@
 #include "store.h" 
 #include "socket.h" 
 
+typedef struct command_s command_t;
+typedef apr_status_t(*command_f) (command_t * self, void * type, char *data, 
+                                  apr_pool_t *ptmp);
+
+struct command_s {
+  char *name;
+  command_f func;
+  char *syntax;
+  char *help;
+#define COMMAND_FLAGS_NONE         0x00000000
+#define COMMAND_FLAGS_DEPRECIATED  0x00000001
+#define COMMAND_FLAGS_EXPERIMENTAL 0x00000002
+#define COMMAND_FLAGS_LINK         0x00000004
+#define COMMAND_FLAGS_BODY         0x00000008
+  int flags;
+};
+
 typedef struct socket_s {
   int is_ssl;
   transport_t *transport;
@@ -59,10 +76,13 @@ typedef struct validation_s {
 
 typedef struct worker_s worker_t;
 typedef struct global_s global_t;
-typedef apr_status_t(*interpret_f)(worker_t * self, worker_t *parent, 
+typedef apr_status_t(*interpret_f)(worker_t *worker, worker_t *parent, 
                                    apr_pool_t *ptmp);
+typedef const char *(*readline_f)(worker_t *worker);
 struct worker_s {
   global_t *global;
+  /* readline function */
+  readline_f readline;
   /* interpreter function */
   interpret_f interpret;
   /* worker config */
@@ -187,23 +207,6 @@ struct global_s {
   int recursiv;
 };
 
-typedef struct command_s command_t;
-typedef apr_status_t(*command_f) (command_t * self, void * type, char *data, 
-                                  apr_pool_t *ptmp);
-
-struct command_s {
-  char *name;
-  command_f func;
-  char *syntax;
-  char *help;
-#define COMMAND_FLAGS_NONE         0x00000000
-#define COMMAND_FLAGS_DEPRECIATED  0x00000001
-#define COMMAND_FLAGS_EXPERIMENTAL 0x00000002
-#define COMMAND_FLAGS_LINK         0x00000004
-#define COMMAND_FLAGS_BODY         0x00000008
-  int flags;
-};
-
 typedef struct line_s {
   char *info;
   char *buf;
